%define major      %{version}

%global libcapnp   %mklibname capnp %{major}
%global libkj      %mklibname kj %{major}
%global devcapnp   %mklibname capnp -d

%global modulename %{name}-c++

Name:           capnproto
Version:        1.0.1
Release:        %mkrel 1
Summary:        A data interchange format and capability-based RPC system
Group:          Development/Other
License:        MIT
URL:            https://capnproto.org
Source0:        https://capnproto.org/%{modulename}-%{version}.tar.gz

# We need C++
BuildRequires:  gcc-c++
BuildRequires:  cmake

Provides:       capnp = %{version}-%{release}
Provides:       capnp%{?_isa} = %{version}-%{release}
Provides:       capnpc = %{version}-%{release}
Provides:       capnpc%{?_isa} = %{version}-%{release}

Requires:       libcapnp%{?_isa} = %{version}-%{release}

%description
Cap'n Proto is an insanely fast data interchange format and capability-based
RPC system. Think JSON, except binary. Or think Protocol Buffers, except
faster. In fact, in benchmarks, Cap'n Proto is INFINITY TIMES faster than
Protocol Buffers.

This package contains the schema compiler and command-line encoder/decoder
tools.

%package -n %{libcapnp}
Summary:        Insanely fast serialization system libraries
Group:          System/Libraries
Provides:       libcapnp = %{version}-%{release}
Provides:       libcapnp%{?_isa} = %{version}-%{release}

%description -n %{libcapnp}
Cap'n Proto is an insanely fast data interchange format and capability-based
RPC system. Think JSON, except binary. Or think Protocol Buffers, except
faster. In fact, in benchmarks, Cap'n Proto is INFINITY TIMES faster than
Protocol Buffers.

%package -n %{libkj}
Summary:        Cap'n Proto KJ Framework Library
Group:          System/Libraries
Provides:       libkj = %{version}-%{release}
Provides:       libkj%{?_isa} = %{version}-%{release}

%description -n %{libkj}
Cap'n Proto is an insanely fast data interchange format and capability-based
RPC system. Think JSON, except binary. Or think Protocol Buffers, except
faster. In fact, in benchmarks, Cap'n Proto is INFINITY TIMES faster than
Protocol Buffers.

This package contains basic utility library called KJ.

%package -n %{devcapnp}
Summary:        Development files and headers for libcapnp
Group:          Development/Other
Requires:       libcapnp%{?_isa} = %{version}-%{release}
Requires:       libkj%{?_isa}= %{version}-%{release}
Provides:       capnproto-devel = %{version}-%{release}
Provides:       capnproto-devel%{?_isa} = %{version}-%{release}

%description -n %{devcapnp}
This package contains the development files and headers for libcapnp.

%prep
%autosetup -n %{modulename}-%{version} -p1

# Disable broken test
## Cf. https://github.com/capnproto/capnproto/issues/1349
## Cf. https://github.com/capnproto/capnproto/issues/1398
sed -e '/TEST(AsyncIo, AncillaryMessageHandler)/,/^}/s/^/\/\//' -i src/kj/async-io-test.c++

%build
# The tests are randomly failing due to poor sparsing support in the build system
export CFLAGS="%{build_cflags} -DHOLES_NOT_SUPPORTED=1"
export CXXFLAGS="%{build_cxxflags} -DHOLES_NOT_SUPPORTED=1"

%cmake -DBUILD_TESTING=ON
%cmake_build

%check
%ctest

%install
%cmake_install

%files
%{_bindir}/capnp
%{_bindir}/capnpc
%{_bindir}/capnpc-c++
%{_bindir}/capnpc-capnp

%files -n %{libcapnp}
%license LICENSE*
%{_libdir}/libcapnp.so.%{major}
%{_libdir}/libcapnpc.so.%{major}
%{_libdir}/libcapnp-json.so.%{major}
%{_libdir}/libcapnp-rpc.so.%{major}
%{_libdir}/libcapnp-websocket.so.%{major}

%files -n %{libkj}
%license LICENSE*
%{_libdir}/libkj.so.%{major}
%{_libdir}/libkj-async.so.%{major}
%{_libdir}/libkj-http.so.%{major}
%{_libdir}/libkj-test.so.%{major}

%files -n %{devcapnp}
%{_includedir}/capnp/
%{_includedir}/kj/
%{_libdir}/libcapnp*.so
%{_libdir}/libkj*.so
%{_libdir}/pkgconfig/capnp*.pc
%{_libdir}/pkgconfig/kj*.pc
%{_libdir}/cmake/CapnProto/


%changelog
* Sun Apr 27 2025 wally <wally> 1.0.1-1.mga10
+ Revision: 2179293
- imported package capnproto

